PAWpySeed: ppot Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
ppot Struct Reference

`#include <utils.h>`

Collaboration diagram for ppot:
[legend]

## Public Attributes
int | num_projs
| number of radial projector functions More...
int | total_projs
| number of projector functions More...
int | lmax
| maximum l-value of any projector More...
funcset_t * | funcs
| funcset for each projector, see funcset More...
double | rmax
double | wave_rmax
| maximum radius of the partial waves More...
double * | pspw_overlap_matrix
| overlap matrix for pseudo partial waves More...
double * | aepw_overlap_matrix
| overlap matrix for all electron partial waves More...
double * | diff_overlap_matrix
| overlap matrix of difference between all electron and partial waves More...
int | proj_gridsize
| number of points on projector radial grid More...
int | wave_gridsize
| number of points on partial wave radial grid More...
int | num_cart_gridpts
| number of real space grid points that can fit in the projector sphere More...
double * | wave_grid
| real radial grid for partial waves More...
double * | kwave_grid
| reciprocal radial grid for partial waves More...
double * | proj_grid
| real radial grid for projector functions More...
double * | smooth_grid
double * | dense_kgrid

## Member Data Documentation

double* ppot::aepw_overlap_matrix

overlap matrix for all electron partial waves

double* ppot::dense_kgrid

double* ppot::diff_overlap_matrix

overlap matrix of difference between all electron and partial waves

funcset_t* ppot::funcs

funcset for each projector, see funcset

double* ppot::kwave_grid

reciprocal radial grid for partial waves

int ppot::lmax

maximum l-value of any projector

int ppot::num_cart_gridpts

number of real space grid points that can fit in the projector sphere

int ppot::num_projs

number of radial projector functions

double* ppot::proj_grid

real radial grid for projector functions

int ppot::proj_gridsize

number of points on projector radial grid

double* ppot::pspw_overlap_matrix

overlap matrix for pseudo partial waves

double ppot::rmax

double* ppot::smooth_grid

int ppot::total_projs

number of projector functions

double* ppot::wave_grid

real radial grid for partial waves

int ppot::wave_gridsize

number of points on partial wave radial grid

double ppot::wave_rmax

maximum radius of the partial waves

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h